\name{AnalyzeTilingCelFiles}
\alias{AnalyzeTilingCelFiles}
\title{ Background correction and RNA normalization for CEL files from an Affymetrix tiling array. }
\description{
AnalyzeTilingCelFiles extracts intensity data from a group of CEL files and returns annotated intensities using information from a BPMAP file. Options can be set to limit the analysis to certain genomic features or regions of interest,thus requiring less memory and computing time.

By default, preforms background correction, quantile normalization, and log2 transform.  This can be disabled by setting ReturnRawIntensities to TRUE, if raw intensity values are desired.

This function returns a matrix, where rows represent probes and columns represent the following values:
	--Unique probe ID
	--Probe start position (in genomic coordinates)
	--Chromosome
	--Sequence
	--Intensity for sample 1
	--Intensity for sample 2
		...
	--Intensity for sample N
}
\usage{
AnalyzeTilingCelFiles(CEL_filenames, BPMAP_filename, outfilename=NULL, iID=NULL, iCHR=NULL, iSTART=NULL, iEND=NULL, makeUniqueID=TRUE, readOnlyNCBI=TRUE, readProbeSeq=FALSE, IgnoreBpmapCelPlatformMismatch=FALSE, ReturnRawIntensities=FALSE)
}
\arguments{
  \item{CEL_filenames}{ A character vector of the path to all CEL file(s) in the analysis. }
  \item{BPMAP_filename}{ The path to the BPMAP file which describes the arrays specified in the cel files. }
  \item{outfilename}{ If specified, the function writes a tab-separated table of normalized intensities. }
  \item{iID}{ Vector of IDs for each interval specified. }
  \item{iCHR}{ Vector of chromosomes for each interval. }
  \item{iSTART}{ Integer vector of the interval start. }
  \item{iEND}{ Integer vector of the interval end. }
  \item{makeUniqueID}{ If TRUE (default), returns a column of unique identifiers for each probe, of the form: chr-start. }
  \item{readOnlyNCBI}{ If TRUE (default), returns ONLY probes that target NCBI sequences, TIGR and Affymetrix controls are ignored. }
  \item{readProbeSeq}{ If TRUE, returns the first 25 bp of the probe sequence. }
  \item{IgnoreBpmapCelPlatformMismatch}{ If TRUE, ignores a mismatch between BPMAP and CEL platforms. (EXPERT ONLY!) }
  \item{ReturnRawIntensities}{ If TRUE, returns raw intensity values associated with the specified regions.  Otherwise (default) preforms RMA-like processing of data using the affy package.  Processing includes background correction, quantile normalization, and a log-2 transform. }
}
\author{ Charles Danko }
\examples{
## Note that executing the following example requires .bpmap and .cel files in the working directory.
## If these files do not, the program will not execute.

## Get the file names in the current working directory.
CEL_NAMES <- dir(pattern=".CEL|.cel");
BPMAP     <- dir(pattern=".bpmap");

## If files are found in the current working directory ... start the analysis!!
if( (NROW(CEL_NAMES) > 0) & (NROW(BPMAP) > 0) ) {
  AnalyzeTilingCelFiles(CEL_NAMES, BPMAP, outfilename="NormalizedData.tsv");
}
}
\keyword{ data }
 
 

