\name{AssociateWithInterval}
\alias{AssociateWithInterval}
\title{ Returns index of association between a probe and a set of genomic intervals. }
\description{
Takes four vectors representing a unique ID, chromosome, start, and end of non-overlapping regions of interest (e.g. known genes, CpG islands, etc.).  Two additional vectors representing the chromosome and start position of probes in a tiling array.  

One additional argument (optional) specifies the length of the probes.  This can be either a vector with one length for each probe, or a scalar if all probes are the same length.  If this argument is not specified, probes are assumed to be 25bp in length.

Returns a vector representing the unique ID of the interval in which each probe can be found.  Values of NA are returned for probes that are located in any of the given genomic intervals.
}
\usage{
AssociateWithInterval(fID, fCHR, fSTART, fEND, pCHR, pSTART, pLENGTH)
}
\arguments{
  \item{fID}{ Vector of unique IDs, representing each interval searched. }
  \item{fCHR}{ Vector of chromosomes, one for each interval searched. }
  \item{fSTART}{ Vector of start positions, one for each interval searched. }
  \item{fEND}{ Vector of end positions, one for the each interval searched. }
  \item{pCHR}{ Vector of chromosomes, one for each probes being annotated. }
  \item{pSTART}{  Vector of start positions, one for each of the probes being annotated.  }
  \item{pLENGTH}{ Vector or scalar representing probe length.  Default is 25bp for each probe. }
}
\author{ Charles Danko }
\examples{
data(KnownGenes)

## Returns probes that fall inside known genes.
Interval <- AssociateWithInterval( KG[,1], KG[,2], KG[,4], KG[,5], Einter[,3], as.integer(Einter[,2]) )
}
\keyword{ data }
