\name{TilingCelFiles2Probesets}
\alias{TilingCelFiles2Probesets}
\title{ Background correction and RNA normalization for CEL files from an Affymetrix tiling array. }
\description{
TilingCelFiles2Probesets extracts intensity data from a group of CEL files and returns annotated intensities using information from a BPMAP file. Options can be set to limit the analysis to certain genomic features or regions of interest,thus requiring less memory and computing time.

Returns a matrix, where rows represent probe sets and columns represent the following:  
	--Unique probeset ID ("chromosome-first probe START position-last probe END position")
	--Probe start position (in genomic coordinates)
	--Chromosome
	--Average normalized intensity for sample 1
	--Average normalized intensity for sample 2
		...
	--Average normalized intensity for sample N

Note that unlike AnalyzeTilingCelFiles, this function reports only 1 average value for all probes in each interval.
}
\usage{
TilingCelFiles2Probesets(CEL_filenames, BPMAP_filename, outfilename=NULL, iID=NULL, iCHR, iSTART, iEND, IgnoreBpmapCelPlatformMismatch=FALSE)
}
\arguments{
  \item{CEL_filenames}{ A character vector of the path to all CEL file(s) in the analysis. }
  \item{BPMAP_filename}{ The path to the BPMAP file which describes the arrays specified in the cel files. }
  \item{outfilename}{ If specified, the function writes a tab-separated table of normalized intensities. }
  \item{iID}{ Vector of IDs for each interval specified.  If NULL (default) creates a unique ID for each interval of the form: "CHR-START-END". }
  \item{iCHR}{ Vector of chromosomes for each interval. }
  \item{iSTART}{ Integer vector of the interval start. }
  \item{iEND}{ Integer vector of the interval end. }
  \item{IgnoreBpmapCelPlatformMismatch}{ If TRUE, ignores a mismatch between BPMAP and CEL platforms. (EXPERT ONLY!) }
}
\author{ Charles Danko }
\examples{
## Note that executing the following example requires .bpmap and .cel files in the working directory.
## If these files do not, the program will not execute.

## Creates a sample interval of the first 1MB of chromosome 1-3.
## This function will return a single value for each interval.
iCHR <- c("chr1", "chr2", "chr3")
iSTART <- rep(1, 3)
iEND <- iSTART + 1e+06

## Get the file names in the current working directory.
CEL_NAMES <- dir(pattern=".CEL|.cel");
BPMAP     <- dir(pattern=".bpmap");

## If files are found in the current working directory ... start the analysis!!
if( (NROW(CEL_NAMES) > 0) & (NROW(BPMAP) > 0) ) {
  TilingCelFiles2Probesets(CEL_NAMES, BPMAP, outfilename="NormalizedData.tsv", iID=NULL, iCHR=iCHR, iSTART=iSTART, iEND=iEND);
}
}
\keyword{ data }
 
 
